% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/aux_getirisdata.R
\name{aux_getirisdata}
\alias{aux_getirisdata}
\title{Download seismic data from IRIS data base}
\usage{
aux_getirisdata(start, duration, sncl, ID_iris = "IrisClient")
}
\arguments{
\item{start}{\code{Posixct} value, start time of the data to query.}

\item{duration}{\code{Numeric} value, length of the data to query, in 
seconds.}

\item{sncl}{\code{Character} vector, SNCL string used to identify station 
and component of interest. These strings should match the time criteria. 
Typically, the SNCL string can be taken from the output of the function
\code{aux_getirisstations}.}

\item{ID_iris}{\code{Character} value, IRIS ID. Default is 
\code{"IrisClient"}.}
}
\value{
\code{List} with downloaded seismic data. For each element in 
\code{sncl}, a list element is created, which in turn contains a list with 
the typical seismic data organisation as, for example, created by 
\code{read_sac()}.
}
\description{
This function accesses the IRIS internet data base of seismic signals and 
downloads seismic data based on the provided SNCL string and time 
information. The downloaded data is converted to the same structure as 
would be expected from \code{read_sac()} or \code{read_mseed()}.
}
\details{
The function makes use of the functionalities provided by the package 
IRISSeismic. It requires a working internet connection to perform the 
download.
}
\examples{

\dontrun{

sncl <- aux_getirisdata(start = as.POSIXct("2010-01-01 22:22:22", 
                                           tz = "UTC"), 
                        duration = 120, 
                        location = c(53, 13), 
                        radius = 1, 
                        component = "BHZ")

data <- aux_getirisdata(start = as.POSIXct("2010-01-01 22:22:22", 
                                           tz = "UTC"), 
                        duration = 120,
                        sncl = sncl$sncl[1])
                        
s <- data[[1]]$signal
t <- data[[1]]$time

plot_signal(data = s, 
            time = t)
}
                     
}
\author{
Michael Dietze
}
\keyword{eseis}
